#!/bin/sh

# Copyright 2009 (c)
# Zebooka (Anton Bondar) <anton@zebooka.com> http://www.zebooka.com
# $Id: zebooka-downloader.sh 180 2009-06-05 16:28:04Z zebooka $
#
# You are free to change, modify, redistribute this script.
# Read supplied LICENSE file for full information.


EXIFTOOL_PARAMS='-r -v0 -fast'
# set photographer by ID, here you can write you configure
Photographer () {
	case $1 in 
		zebooka)
			PHOTO_PREFIX='BOA_'
			if [ ! $UPLOAD_TO ]; then
				UPLOAD_TO='/home/zebooka/FOTO/'
			else
				echo "\033[0;39mYou've selected custom UPLOAD_TO path, so please specify prefix or leave it empty for default '\033[1;36m${PHOTO_PREFIX}\033[0;39m'."
				read -p 'Prefix: ' PHOTO_PREFIX_TMP
				if [ $PHOTO_PREFIX_TMP ]; then
					PHOTO_PREFIX=$PHOTO_PREFIX_TMP
					echo "You've selected '\033[1;36m${PHOTO_PREFIX}\033[0;39m' prefix."
				else
					echo "Using default prefix '\033[1;36m${PHOTO_PREFIX}\033[0;39m'."
				fi
				echo "\033[0;2;39m"
			fi
			exiftool $EXIFTOOL_PARAMS -if '$ShutterCount' -if '$InternalSerialNumber eq "4123986"' -d '%Y/%Y.%m_%B/%d' "-FileName<${UPLOAD_TO}\${DateTimeOriginal}/${PHOTO_PREFIX}e\${ShutterCount}%-c.%e" "${DOWNLOAD_FROM}"
			;;
		giraffo)
			PHOTO_PREFIX='CHV_'
			if [ ! $UPLOAD_TO ]; then
				UPLOAD_TO='/home/giraffo/FOTO/'
			else
				echo "\033[0;39mYou've selected custom UPLOAD_TO path, so please specify prefix or leave it empty for default '\033[1;36m${PHOTO_PREFIX}\033[0;39m'."
				read -p 'Prefix: ' PHOTO_PREFIX_TMP
				if [ $PHOTO_PREFIX_TMP ]; then
					PHOTO_PREFIX=$PHOTO_PREFIX_TMP
					echo "You've selected '\033[1;36m${PHOTO_PREFIX}\033[0;39m' prefix."
				else
					echo "Using default prefix '\033[1;36m${PHOTO_PREFIX}\033[0;39m'."
				fi
				echo "\033[0;2;39m"
			fi
			exiftool $EXIFTOOL_PARAMS -if '$ShutterCount' -if '$InternalSerialNumber eq "8041881"' -d '%Y/%Y.%m_%B/%d' "-FileName<${UPLOAD_TO}\${DateTimeOriginal}/${PHOTO_PREFIX}c\${ShutterCount}%-c.%e" "${DOWNLOAD_FROM}"
			;;
		old)
			PHOTO_PREFIX='OLD_'
			if [ ! $UPLOAD_TO ]; then
				Error "Please specify UPLOAD_TO parameter manually."
				exit 120
			else
				echo "\033[0;39mPlease specify prefix or leave it empty for default '\033[1;36m${PHOTO_PREFIX}\033[0;39m'."
				read -p 'Prefix: ' PHOTO_PREFIX_TMP
				if [ $PHOTO_PREFIX_TMP ]; then
					PHOTO_PREFIX=$PHOTO_PREFIX_TMP
					echo "You've selected '\033[1;36m${PHOTO_PREFIX}\033[0;39m' prefix."
				else
					echo "Using default prefix '\033[1;36m${PHOTO_PREFIX}\033[0;39m'."
				fi
				echo "\033[0;2;39m"
			fi

			echo "\033[0;35mPentax *ist DS\033[2;39m"
			exiftool $EXIFTOOL_PARAMS -if '$ShutterCount' -if '$InternalSerialNumber eq "6011443"' -d '%Y/%Y.%m_%B/%d' "-FileName<${UPLOAD_TO}\${DateTimeOriginal}/${PHOTO_PREFIX}b\${ShutterCount}%-c.%e" "${DOWNLOAD_FROM}"
			
			# echo "\033[0;35mPentax K100D\033[2;39m"
			# exiftool $EXIFTOOL_PARAMS -if '$ShutterCount' -if '$InternalSerialNumber eq "6374615"' -d '%Y/%Y.%m_%B/%d' "-FileName<${UPLOAD_TO}\${$
			
			# echo "\033[0;35mPentax K100D Super\033[2;39m"
			# exiftool $EXIFTOOL_PARAMS -if '$ShutterCount' -if '$InternalSerialNumber eq "6609148"' -d '%Y/%Y.%m_%B/%d' "-FileName<${UPLOAD_TO}\${DateTimeOriginal}/${PHOTO_PREFIX}d\${ShutterCount}%-c.%e" "${DOWNLOAD_FROM}"
			;;
		raw)
			if [ ! $UPLOAD_TO ]; then
				Error "Please specify UPLOAD_TO parameter manually."
				exit 120
			fi
			exiftool $EXIFTOOL_PARAMS if '$DateTimeOriginal' -d '%Y/%Y.%m_%B/%d' "-FileName<${UPLOAD_TO}\${DateTimeOriginal}/%f%-c.%e" "${DOWNLOAD_FROM}"
			;;
		*) # default parameters
			Error "Unknown photographer ID supplied."
			Usage
			exit 1
			;;
	esac
}

Photographers () {
	echo "\033[0mList of configured photographers:\033[0m"
	echo "\033[1;32m   zebooka  giraffo  \033[0;39m"
	echo "\033[1;34m   old  raw\033[0;39m"
	echo ""
}

# don't change anything below (unless you are guru)
# ##############################################################################

Error () { echo "\033[0;30;41m ERROR: \033[1;37m${1} \033[0;39;49m\n"; }
Warning () { echo "\033[0;30;43m WARNING: \033[1;30m${1} \033[0;39;49m\n"; }
Success () { echo "\033[0;30;42m OK: \033[1;37m${1} \033[0;39;49m\n"; }
Notice () { echo "\033[0;30;46m NOTICE: \033[1;30m${1} \033[0;39;49m\n"; }

# output usage info
Usage () {
	echo "\033[4mUSAGE\033[0m:"
	echo "   \033[1m${0}\033[0m [-p PHOTOGRAPHER_ID] [-u UPLOAD_TO] DOWNLOAD_FROM"
	echo ""
	echo "\033[4mPARAMETERS\033[0m:"
	echo "   -p PHOTOGRAPHER_ID     No prompting for photographer ID (PID), use"
	echo "                          specified PID."
	echo "   -u UPLOAD_TO           Upload photos to UPLOAD_TO path. Note that"
	echo "                          photographer ID also specifies UPLOAD_TO path."
	echo "                          Use this option to manually overide this path."
	echo "   -h                     This help message."
	echo ""
}

# print header
echo ""
echo "\033[1mZEBOOKA-DOWNLOADER\033[0;2m, version$Rev: 180 $Hide"
echo "\033[0m(c) Copyright 2009, \033[32mZebooka (Anton Bondar)  \033[36m<anton@zebooka.com>  http://www.zebooka.com"
echo "\033[0;39;49m"

# get params
while getopts ":hu:p:" Option
do
	case $Option in
		h)
			Usage
			exit 0
			;;
		p)
			PHOTOGRAPHER_ID=$OPTARG
			;;
		u)
			UPLOAD_TO=$OPTARG
			;;
	esac
done
shift `expr $OPTIND - 1`

DOWNLOAD_FROM=$1
if [ ! $DOWNLOAD_FROM ]; then
	Error "No DOWNLOAD_FROM path specified."
	Usage
	exit 3
fi

if [ ! $PHOTOGRAPHER_ID ]; then
	Photographers
	read -p 'Photographer: ' PHOTOGRAPHER_ID
	echo ""
fi

# citate
echo "\033[0;1mIf your photographs aren't good enough, you're not close enough\033[0m —— Robert Capa\033[0m"
echo ""

echo "\033[0;39mDownloading photos for photographer \033[32m${PHOTOGRAPHER_ID}\033[2;39m"
Photographer "${PHOTOGRAPHER_ID}"

echo "\033[0m"
Success "All directories processed succefully."
echo "\033[0;39;49m"
sleep 2s
exit 0

