#!/bin/sh

# Copyright 2009 (c)
# Zebooka (Anton Bondar) <anton@zebooka.com> http://www.zebooka.com
# $Id: zebooka-resizer.sh 243 2009-07-13 09:21:13Z zebooka $
#
# You are free to change, modify, redistribute this script.
# Read supplied LICENSE file for full information.

# TODO:
# - fix bugs with relative paths

# don't change anything below (unless you are guru)
# ##############################################################################

Error () { echo "\033[0;30;41m ERROR: \033[1;37m${1} \033[0;39;49m\n"; }
Warning () { echo "\033[0;30;43m WARNING: \033[1;30m${1} \033[0;39;49m\n"; }
Success () { echo "\033[0;30;42m OK: \033[1;37m${1} \033[0;39;49m\n"; }
Notice () { echo "\033[0;30;46m NOTICE: \033[1;30m${1} \033[0;39;49m\n"; }

# output usage info
Usage () {
	echo "\033[4mUSAGE\033[0m:"
	echo "   \033[1m${0}\033[0m [-h] [-r] [-q QUALITY] [-s WxH] FROM_PATH [TO_PATH]"
	echo ""
	echo "   FROM_PATH              Images from this folder are processed."
	echo "   TO_PATH                They are saved to this folder. By default"
	echo "                          script will create subfolder 'resized-YYYY-MM-DD'"
	echo ""
	echo "\033[4mPARAMETERS\033[0m:"
	echo "   -h                     This help message."
	echo "   -e                     Remove EXIF from resized image."
	echo "   -r or -R               Process directory recursively. [NOT IMPLEMENTED YET]"
	echo "   -q QUALITY             Quality of resized jpeg, from 0% to 100%. Default: 85%"
	echo "   -d WxH                 Max dimentions (width and height) to fit image. Default: 700x500"
	echo "   -s SHARP               Sharp image with unsharpen mask. Types: no, light, hard, extra."
	echo "                          Default: light. For manual sharpening define:"
	echo "                          RADIUSxSIGMA+AMOUNT+THRESHOLD (more -> man ImageMagick)."
	echo ""
}

# process folder
ResizeFolder () {
	cd "$1"
	mkdir -vp "$2"
	TTT=`ls -1 | grep -i -E '^.*(jpg|jpeg)$' -`
	IFS_OLD=$IFS
	IFS=$(echo '\n\b')
	for PHOTO_FILE in $TTT
	do
		# echo "$PHOTO_FILE"
		# Matching GIMP unsharp
		# Take gimp radius and add 1 => IM sigma
		# Threshold divide by 255    => IM Threshold
        # So  GIMP  radius=2  amount=1.5  threshold=5  results in -unsharp 0×3+1.5+0.0196
		convert "$PHOTO_FILE" -verbose -unsharp $OPT_SHARP -quality $OPT_QUALITY $OPT_NOEXIF -resize $OPT_SIZE\> "${2}${PHOTO_FILE}"
	done
	# scan subfolders, if recursive
	if [ "$OPT_RECURSIVE" ]; then
		TTT=`ls -1d */`
		for PHOTO_FOLDER in $TTT
		do
			echo "Recursing into \033[4m${1}${PHOTO_FOLDER}\033[0m"
			ResizeFolder "${1}${PHOTO_FOLDER}" "${2}${PHOTO_FOLDER}"
		done
	fi
	IFS=$IFS_OLD
}

# print header
echo ""
echo "\033[1mZEBOOKA-RESIZER\033[0;2m, version$Rev: 243 $Hide"
echo "\033[0m(c) Copyright 2009, \033[32mZebooka (Anton Bondar)  \033[36m<anton@zebooka.com>  http://www.zebooka.com"
echo "\033[0;39;49m"

if [ ! `which convert` ]; then
	Error "ImageMagick required for this script to work. Please install it."
	exit 1
fi

# get params
OPT_SIZE="700x500"
OPT_QUALITY="85%"
OPT_NOEXIF=""
OPT_SHARP=" 0x3+0.7+0 "
while getopts ":rRhed:q:s:" Option
do
	case $Option in
		e) OPT_NOEXIF="-strip" ;;
		q) OPT_QUALITY=$OPTARG ;;
		d) OPT_SIZE=$OPTARG ;;
		r|R) OPT_RECURSIVE=1 ;;
		s) 
			case $OPTARG in
				no) OPT_SHARP=" 0 " ;;
				light) ;;
				hard) OPT_SHARP=" 0x3+1.3+0 " ;;
				extra) OPT_SHARP=" 0x5+1.7+0 " ;;
				*) OPT_SHARP=" ${OPTARG} " ;;
			esac
			;;
		h)
			Usage
			exit 0
			;;
	esac
done
shift `expr $OPTIND - 1`

OPT_FROM=$1
if [ ! "$OPT_FROM" ]; then
	Error "No FROM_PATH specified."
	Usage
	exit 3
fi
echo "Processing photos from: \033[4m$OPT_FROM\033[0m"

OPT_TO=$2
if [ ! "$OPT_TO" ]; then
	OPT_TO="`dirname "$OPT_FROM"`/`basename "$OPT_FROM"`/resized-`date +%Y%m%d-%H%M%S`/"
	echo "Notice: TO_PATH for resized files not specified. Using default: \033[4m$OPT_TO\033[0m"
else
	echo "Resized files will be saved to: \033[4m$OPT_TO\033[0m"
fi

echo ""
ResizeFolder "$OPT_FROM" "$OPT_TO"

echo "\033[0m"
Success "Directory $OPT_FROM processed succefully."
echo "\033[0;39;49m"
#sleep 2s
exit 0

